from . import GaqHub
from pyramid.threadlocal import get_current_request

def gaq_setup( account_id , single_push=False , request=None ):
    if request is None:
       request= get_current_request()
    request._gaq= GaqHub( account_id , single_push=single_push )

def gaq_setAccount(account_id,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.gaq_setAccount( account_id )

def gaq_setSinglePush(bool_value,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.setSinglePus( bool_value )

def gaq_trackEvent(track_dict,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.trackEvent(track_dict)
    
def gaq_setCustomVar(index,name,value,opt_scope=None,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.setCustomVar(index,name,value,opt_scope=opt_scope)

def gaq_setDomainName(domain_name,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.setDomainName(domain_name)

def gaq_setAllowLinker(bool_allow,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.setAllowLinker(bool_allow)

def gaq_addTrans(track_dict,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.addTrans(track_dict)
    
def gaq_addItem(track_dict,request=None):
    if request is None:
       request= get_current_request()
    request._gaq.addItem(track_dict)

def gaq_trackTrans(request=None):
    if request is None:
       request= get_current_request()
    request._gaq.trackTrans()
    
def gaq_as_html(request=None):
    if request is None:
       request= get_current_request()
    return request._gaq.as_html()



"""gaq_helper installation script.
"""
import os

from setuptools import setup
from setuptools import find_packages

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, "README.txt")).read()
README = README.split("\n\n", 1)[0] + "\n"

requires = []

setup(name="gaq_hub",
      version="0.0.6",
      description="Lightweight Google Analytics support",
      long_description=README,
      classifiers=[
        "Intended Audience :: Developers",
        "Framework :: Pylons",
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
        ],
      keywords="web pylons",
      py_modules=['gaq_hub'],
      author="Jonathan Vanasco",
      author_email="jonathan@findmeon.com",
      url="https://github.com/jvanasco/gaq_hub",
      license="MIT",
      packages=find_packages(),
      include_package_data=True,
      zip_safe=False,
      tests_require = requires,
      install_requires = requires,
      )

